@@ -14,8 +14,9 @@ class Communicate(Thread):
 		self.Parent = parent
 		self.ignore = False
 		self.connected = False
-		self.startCode = chr(8) + chr(0) + chr(128) + chr(9) + chr(0)+ chr(4) + "fwd" + chr(0)
-		self.stopCode = chr(0) + chr(1) #FIXME: doesn't do anything
+		self.codes = {}
+		self.codes["start"] = chr(8) + chr(0) + chr(128) + chr(9) + chr(0)+ chr(4) + "fwd" + chr(0)
+		self.codes["stop"] = chr(0) + chr(1) #FIXME: doesn't do anything
 
 	def run(self):
 		pass
@@ -51,7 +52,7 @@ class Communicate(Thread):
 	def startMachine(self, ignore=""):
 		if self.connected:
 			try:
-				self.socket.send(self.startCode)
+				self.socket.send(self.codes["start"])
 				commands.getoutput("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Started coffeemaker\"")
 			except:
 				commands.getoutput("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Failed, try to reconnect\"")
@@ -62,7 +63,7 @@ class Communicate(Thread):
 	def stopMachine(self, ignore=""):
 		if self.connected:
 			try:
-				self.socket.send(self.stopCode)
+				self.socket.send(self.codes["stop"])
 				commands.getoutput("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Stopped coffeemaker\"")
 			except:
 				commands.getoutput("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Failed, try to reconnect\"")
